@@ -67,9 +67,9 @@
 #' @param save_as If not NULL, the file name to which the downloaded
 #' data will be saved on the disk as a .csv
 #' @param tscale A character vector of length one determining what
-#' chronostratigraphic timescale will be applied to the data. "ICS2013"
-#' will retain the PBDB ICS 2013 standard. "GTS2020" will update all
-#' early and late interval ages to the GTS2020 standard, using a
+#' chronostratigraphic timescale will be applied to the data. "ICS_2013"
+#' will retain the PBDB ICS 2013 standard. "GTS_2020" will update all
+#' early and late interval ages to the GTS_2020 standard, using a
 #' lookup table supplied with the function. Alternatively, the
 #' pathway to a custom .csv file  with columns Interval, FAD and
 #' LAD where Interval are the names of the early and late intervals
@@ -89,7 +89,7 @@
 get_pbdb <- function(taxon = NULL, interval = NULL, mode = "occurrence", res = "all", fields = c("ident", "coords", "class"),
                      ex_taxon = NULL, area = NULL, ex_area = NULL, invert_area = FALSE, litho = NULL, invert_litho = FALSE,
                      env = NULL, ex_env = NULL, invert_env = NULL, pres = NULL, idqual = NULL,
-                     return_url = FALSE, return_data = TRUE, save_as = NULL, tscale = "ICS2013", wait = Inf) {
+                     return_url = FALSE, return_data = TRUE, save_as = NULL, tscale = "ICS_2013", wait = Inf) {
 
 
   #taxon = "Dinosauria"
@@ -195,8 +195,8 @@ get_pbdb <- function(taxon = NULL, interval = NULL, mode = "occurrence", res = "
         warning("Three or more interval names were provided - only the first and last will be used")
       }
       interval <- interval[c(1, length(interval))]
-      GTS2020 <- get("GTS2020")
-      interval <- c(GTS2020$FAD[match(interval[1], GTS2020$Interval)], GTS2020$LAD[match(interval[2], GTS2020$Interval)])
+      GTS_2020 <- get("GTS_2020")
+      interval <- c(GTS_2020$FAD[match(interval[1], GTS_2020$Interval)], GTS_2020$LAD[match(interval[2], GTS_2020$Interval)])
     }
     if(is.numeric(interval)) {
       if(length(interval) > 2) {
@@ -516,11 +516,11 @@ get_pbdb <- function(taxon = NULL, interval = NULL, mode = "occurrence", res = "
       unlink(del)
       # perform redating if specified
       do_redate = FALSE
-      if(tscale == "ICS2013") {
+      if(tscale == "ICS_2013") {
         do_redate <- FALSE
       }
-      if(tscale == "GTS2020") {
-        tscale <- get("GTS2020")
+      if(tscale == "GTS_2020") {
+        tscale <- get("GTS_2020")
         tscale <- tscale[,c("Interval", "FAD", "LAD")]
         do_redate <- TRUE
       }
